{%- if pagename != "search" %}
<form class="navbar-form navbar-left" role="search" action="{{ pathto('search') }}" method="get">
  <div class="form-group">
    <input type="hidden" name="check_keywords" value="yes" />
    <input type="hidden" name="area" value="default" />
    <input id="navbar-search-input" type="text" class="form-control" placeholder="Search Documentation" name="q" />
  </div>
  <button id="navbar-search-submit" type="submit" class="btn btn-default"><i class="fa fa-search"></i></button>
</form>
{%- endif %}
