
.wrapper-content-right .section {
    margin-top: 0; /* 32px;*/
    margin-bottom: 0; /* 新增 */
}

.wrapper-content-right > .section {
    margin-top: 0px;
    margin-bottom: 0; /* 新增 */
}

.toctree {
    padding-left: 0;
    list-style: none;
    padding-bottom: 0px;
}

.toctree li {
    list-style: none;
}

a.current, a.current-active {
    font-weight: bold;
}

.highlight {
    font-size: 14px;
    background: #f8f8f8;
}

.highlight pre {
    padding: 12px; /*15px;*/
    /*border: 1px solid #e1e4e5;*/
    /*#ccc;*/
    color: #3f475a;
    border-radius: 2px;
    background: #f5f6fa none repeat scroll 0 0;/*f0f0f0*/
}

.highlight .c1 {
    color: #408080;
}

.highlight .s1 {
    color: #BA2121;
}

.highlight .s2 {
    color: #BA2121;
}

.highlight .kn {
    color: #008000;
}

.highlight .nn {
    color: #0000FF;
}




blockquote {
    /*font-size: 20px;
    border-left: 0px;
    padding: 0px 0px;*/

    font-size: 16px;
    margin-left: 24px;
    line-height: 24px;
    margin-bottom: 24px;
}

/** admonitions **/

div.admonition p {
    padding: 10px 0;
    margin: 0;
}

div.admonition {
    padding: 0 0 0 105px;
    margin: 20px 0;
    border-left: 0;
}

div.admonition ul {
    padding-top: 10px;
    padding-bottom: 10px;
    margin: 0;
}

div.note {
    background: url(../images/admonition/note.png) no-repeat top left;
}

div.seealso {
    background: url(../images/admonition/seealso.png) no-repeat top left;
}

div.tip {
    background: url(../images/admonition/tip.png) no-repeat top left;
}

div.caution {
    background: url(../images/admonition/caution.png) no-repeat top left;
}

div.warning {
    background: url(../images/admonition/warning.png) no-repeat top left;
}

div.danger {
    background: url(../images/admonition/danger.png) no-repeat top left;
}

@media only screen and (-webkit-min-device-pixel-ratio: 2) {

    div.note {
        background-image: url(../images/admonition/note@2x.png);
        background-size: 90px 78px;
    }

    div.seealso {
        background-image: url(../images/admonition/seealso@2x.png);
        background-size: 90px 78px;
    }

    div.tip {
        background-image: url(../images/admonition/tip@2x.png);
        background-size: 90px 78px;
    }

    div.caution {
        background-image: url(../images/admonition/caution@2x.png);
        background-size: 90px 78px;
    }

    div.warning {
        background-image: url(../images/admonition/warning@2x.png);
        background-size: 90px 78px;
    }

    div.danger {
        background-image: url(../images/admonition/danger@2x.png);
        background-size: 90px 78px;
    }

}

.note .admonition-title,
.seealso .admonition-title,
.tip .admonition-title,
.caution .admonition-title,
.warning .admonition-title,
.danger .admonition-title {
    padding: 10px 0 0 0;
    font-weight: bold;
    color: #000000;
    text-transform: capitalize
}

.bs-docs-sidenav > li {
    display: none;
}




/** MENUE **/

.bs-docs-sidenav .toctree li {
    padding: 3px 0px;
    line-height: 16px;
}

.bs-docs-sidenav .toctree .project {
    padding-left: 16px;
    line-height: 36px;
    display: block;
    font-size: 16px;
    font-weight: bold;
    color: #9aa1b1;
}

.bs-docs-sidenav .toctree p.caption {
    display: block;
    padding-left: 2em;
    line-height: 36px;
    margin-bottom: 0;
}
.bs-docs-sidenav .toctree p.caption .caption-text {
    display: inline-block;
    cursor: pointer;
    padding-right: 28px;
    font-size: 14px;
    font-weight: bold;
    color: #3f475a;
    background: url("../images/triangle-open.png") 8px no-repeat;
    background-size: 8px;
    background-position: right center;

}
.bs-docs-sidenav .toctree p.caption .caption-text.close {
    background: url("../images/triangle-close.png") 8px no-repeat;
    background-size: 8px;
    background-position: right center;
}
.bs-docs-sidenav .toctree ul li {
    padding-left: 3em;
    line-height: 16px;
    margin: 10px 0;
}
.bs-docs-sidenav .toctree ul li.current {
    border-left: 3px solid #2D60E0;
}

.bs-docs-sidenav .toctree li a {
    text-decoration: none;
    font-size: 12px;
    line-height: 16px;
    color: #7b8293;
}
.bs-docs-sidenav .toctree li a.project :hover {
    color: #2D60E0;
}

.bs-docs-sidenav .toctree li.current > a,
.bs-docs-sidenav .toctree li.active > a,
.bs-docs-sidenav .toctree li.current > a code,
.bs-docs-sidenav .toctree li.active > a code {
    font-weight: bold; /* bold 500 */
    color: #2D60E0;
}

.bs-docs-sidenav ul {
    margin-bottom: 0px;
}

.bs-docs-sidenav .toctree ul ul ul {
    display: none;
}

.bs-docs-sidenav .toctree li.current > ul,
.bs-docs-sidenav .toctree ul li.active > ul {
    display: block !important;
}
.bs-docs-sidenav {
    padding-left: 0px;
}
.bs-docs-sidebar {
    padding: 8px 16px;
    margin-bottom: 20px;
    padding-left: 0;
}

/* menu bottom extra nav link */
.bs-docs-sidenav .toctree li.border-top {
    border-top: 1px solid #e7e7e7;
    padding-top: 16px;
    margin-top: 16px;
}



.search-link {
    position: relative;
    padding-left: 16px;
}

.affix {
    position: fixed !important;
    top: 20px;
}

#nav-affix {
    overflow-y: auto;
    width: 240px;
}

.wrapper-navleft {
    padding: 0px;
    border: 0px;
}
.wrapper-navleft .bs-docs-sidebar {
    border: 1px solid #e7e7e7;
}
.wrapper-content-right li {
    font-size: 16px;
    line-height: 1.5em;
    margin: 0 24px;
}

h1 code,
h2 code,
h3 code,
h4 code,
h5 code,
h6 code {
    border: 0;
}

a code {
    border: 0;
    font-weight: normal;
}

div.topic {
    border: 0;
}
